package javax.net;

import java.net.InetAddress;
import java.net.UnknownHostException;
import java.io.IOException;
import java.net.SocketException;
import java.net.Socket;

public abstract class SocketFactory
{
    private static SocketFactory theFactory;
    
    protected SocketFactory() {
    }
    
    public static SocketFactory getDefault() {
        synchronized (SocketFactory.class) {
            if (SocketFactory.theFactory == null) {
                SocketFactory.theFactory = new DefaultSocketFactory();
            }
        }
        return SocketFactory.theFactory;
    }
    
    public Socket createSocket() throws IOException {
        UnsupportedOperationException cause = new UnsupportedOperationException();
        SocketException ex = new SocketException("Unconnected sockets not implemented");
        ex.initCause(cause);
        throw ex;
    }
    
    public abstract Socket createSocket(String p0, int p1) throws IOException, UnknownHostException;
    
    public abstract Socket createSocket(String p0, int p1, InetAddress p2, int p3) throws IOException, UnknownHostException;
    
    public abstract Socket createSocket(InetAddress p0, int p1) throws IOException;
    
    public abstract Socket createSocket(InetAddress p0, int p1, InetAddress p2, int p3) throws IOException;
}
